`xotl.tools.bases`:mod: - Numeric base 32 and base 64 integer representations
=============================================================================

.. testsetup::

   from xotl.tools.bases import *

.. automodule:: xotl.tools.bases
   :members: int2str, str2int, B32, B64
